@@ -1,10 +1,12 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2003-2006 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ * 2003-2020 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ *
  * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -21,7 +23,7 @@
 
 int main(int argc, char **argv)
 {
-	short *impulsetab = gen_impulsetab(IMPULSE_W_SHIFT, IMPULSE_N_SHIFT, IMPULSE_CUTOFF);
+	int32_t *impulsetab = gen_impulsetab(IMPULSE_W_SHIFT, IMPULSE_N_SHIFT, IMPULSE_CUTOFF);
 	int n = (1 << IMPULSE_N_SHIFT) * (1 << IMPULSE_W_SHIFT);
 	int i;
 
@@ -32,12 +34,12 @@ int main(int argc, char **argv)
 
 	printf("#define IMPULSE_N_SHIFT %d\n", IMPULSE_N_SHIFT);
 	printf("#define IMPULSE_W_SHIFT %d\n", IMPULSE_W_SHIFT);
-	printf("static const short base_impulse[] = {");
+	printf("static const int32_t base_impulse[] = {");
 	for (i=0; i<n; i++) {
 		if ((i & IMPULSE_W_MASK) == 0) {
 			printf("\n\t");
 		}
-		printf("%6d,", impulsetab[i]);
+		printf("%9d,", impulsetab[i]);
 	}
 	printf("\n};\n");
 
