@@ -1,30 +1,36 @@
 /*
  * gbsplay is a Gameboy sound player
  *
- * 2015 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
+ * 2015-2020 (C) by Tobias Diedrich <ranma+gbsplay@tdiedrich.de>
  *
  * Licensed under GNU GPL v1 or, at your option, any later version.
  */
 
-#include "common.h"
-
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 
+#include "common.h"
 #include "plugout.h"
 
 static FILE *file;
-static long cycles_prev = 0;
+static cycles_t cycles_prev = 0;
 
-static long regparm iodumper_open(enum plugout_endian endian, long rate)
+static long iodumper_open(enum plugout_endian *endian, long rate, long *buffer_bytes, const struct plugout_metadata metadata)
 {
+	int fd;
+
+	UNUSED(endian);
+	UNUSED(rate);
+	UNUSED(buffer_bytes);
+	UNUSED(metadata);
+
 	/*
 	 * clone and close STDOUT_FILENO
 	 * to make sure nobody else can write to stdout
 	 */
-	int fd = dup(STDOUT_FILENO);
+	fd = dup(STDOUT_FILENO);
 	if (fd == -1) return -1;
 	(void)close(STDOUT_FILENO);
 	file = fdopen(fd, "w");
@@ -32,15 +38,16 @@ static long regparm iodumper_open(enum plugout_endian endian, long rate)
 	return 0;
 }
 
-static int regparm iodumper_skip(int subsong)
+static int iodumper_skip(int subsong)
 {
+	cycles_prev = 0;
 	fprintf(file, "\nsubsong %d\n", subsong);
 	fprintf(stderr, "dumping subsong %d\n", subsong);
 
 	return 0;
 }
 
-static int regparm iodumper_io(long cycles, uint32_t addr, uint8_t val)
+static int iodumper_io(cycles_t cycles, uint32_t addr, uint8_t val)
 {
 	long cycle_diff = cycles - cycles_prev;
 
@@ -50,7 +57,7 @@ static int regparm iodumper_io(long cycles, uint32_t addr, uint8_t val)
 	return 0;
 }
 
-static void regparm iodumper_close(void)
+static void iodumper_close(void)
 {
 	fflush(file);
 	fclose(file);
